@@ -17,11 +17,13 @@ __docformat__ = 'restructuredtext'
 
 from zope.schema.vocabulary import SimpleVocabulary
 
-from zope.formlib.widget import SimpleInputWidget, renderElement
-from zope.formlib.widget import DisplayWidget
 from zope.formlib.i18n import _
+from zope.formlib.itemswidgets import DropdownWidget
 from zope.formlib.itemswidgets import RadioWidget
-from zope.formlib.itemswidgets import SelectWidget, DropdownWidget
+from zope.formlib.itemswidgets import SelectWidget
+from zope.formlib.widget import DisplayWidget
+from zope.formlib.widget import SimpleInputWidget
+from zope.formlib.widget import renderElement
 
 
 class CheckBoxWidget(SimpleInputWidget):
@@ -35,7 +37,7 @@ class CheckBoxWidget(SimpleInputWidget):
     extra = ''
 
     def __init__(self, context, request):
-        super(CheckBoxWidget, self).__init__(context, request)
+        super().__init__(context, request)
         self.required = False
 
     def __call__(self):
@@ -45,7 +47,7 @@ class CheckBoxWidget(SimpleInputWidget):
             kw = {'checked': 'checked'}
         else:
             kw = {}
-        return "%s %s" % (
+        return "{} {}".format(
             renderElement(self.tag,
                           type='hidden',
                           name=self.name + ".used",
@@ -73,7 +75,7 @@ class CheckBoxWidget(SimpleInputWidget):
     def hasInput(self):
         """Check whether the field is represented in the form."""
         return self.name + ".used" in self.request.form or \
-            super(CheckBoxWidget, self).hasInput()
+            super().hasInput()
 
     def _getFormInput(self):
         """Returns the form input used by `_toFieldValue`.
