@@ -11,12 +11,12 @@
 # FOR A PARTICULAR PURPOSE.
 #
 ##############################################################################
-"""
-
-$Id: namedtemplate.py 112015 2010-05-05 18:27:23Z tseaver $
+"""BBB
 """
 
 # BBB
-from zope.browserpage.namedtemplate import (
-    INamedTemplate, NamedTemplateImplementation, implementation,
-    NamedTemplate, NamedTemplatePathAdapter)
+from zope.browserpage.namedtemplate import INamedTemplate
+from zope.browserpage.namedtemplate import NamedTemplate
+from zope.browserpage.namedtemplate import NamedTemplateImplementation
+from zope.browserpage.namedtemplate import NamedTemplatePathAdapter
+from zope.browserpage.namedtemplate import implementation
