@@ -13,39 +13,50 @@
 ##############################################################################
 """Source widgets support
 """
+import base64
 import xml.sax.saxutils
 
-from zope.component import adapter, getMultiAdapter
-from zope.interface import implementer
 import zope.browser.interfaces
 import zope.schema.interfaces
-from zope.schema.interfaces import \
-    ISourceQueriables, ValidationError, IVocabularyTokenized, IIterableSource
+from zope.component import adapter
+from zope.component import getMultiAdapter
+from zope.interface import implementer
+from zope.schema.interfaces import IIterableSource
+from zope.schema.interfaces import ISourceQueriables
+from zope.schema.interfaces import IVocabularyTokenized
+from zope.schema.interfaces import ValidationError
 
 import zope.formlib.interfaces
-import zope.formlib.widget
 import zope.formlib.itemswidgets
-from zope.formlib._compat import imap
-from zope.formlib.interfaces import (
-    WidgetInputError,
-    MissingInputError,
-    ISourceQueryView,
-    IWidgetInputErrorView,
-    IDisplayWidget,
-    IInputWidget)
+import zope.formlib.widget
 from zope.formlib.i18n import _
-from zope.formlib.widgets import (
-    SelectWidget, RadioWidget, MultiSelectWidget, OrderedMultiSelectWidget,
-    MultiCheckBoxWidget, MultiSelectSetWidget, MultiSelectFrozenSetWidget)
-from zope.formlib.widget import DisplayWidget, InputWidget
-from zope.formlib._compat import safeBase64Encode
+from zope.formlib.interfaces import IDisplayWidget
+from zope.formlib.interfaces import IInputWidget
+from zope.formlib.interfaces import ISourceQueryView
+from zope.formlib.interfaces import IWidgetInputErrorView
+from zope.formlib.interfaces import MissingInputError
+from zope.formlib.interfaces import WidgetInputError
+from zope.formlib.widget import DisplayWidget
+from zope.formlib.widget import InputWidget
+from zope.formlib.widgets import MultiCheckBoxWidget
+from zope.formlib.widgets import MultiSelectFrozenSetWidget
+from zope.formlib.widgets import MultiSelectSetWidget
+from zope.formlib.widgets import MultiSelectWidget
+from zope.formlib.widgets import OrderedMultiSelectWidget
+from zope.formlib.widgets import RadioWidget
+from zope.formlib.widgets import SelectWidget
+
+
+def safeBase64Encode(obj):
+    return base64.b64encode(
+        obj.encode()).strip().replace(b'=', b'_').decode()
 
 
 @implementer(IDisplayWidget)
 class SourceDisplayWidget(DisplayWidget):
 
     def __init__(self, field, source, request):
-        super(SourceDisplayWidget, self).__init__(field, request)
+        super().__init__(field, request)
         self.source = source
 
     required = False
@@ -122,7 +133,7 @@ class SourceInputWidget(InputWidget):
     _error = None
 
     def __init__(self, field, source, request):
-        super(SourceInputWidget, self).__init__(field, request)
+        super().__init__(field, request)
         self.source = source
         self.terms = getMultiAdapter((source, self.request),
                                      zope.browser.interfaces.ITerms)
@@ -200,13 +211,13 @@ class SourceInputWidget(InputWidget):
         if value == field.missing_value:
             result.append('  <div class="row">')
             result.append('    <div class="label">')
-            result.append(u'     ' +
+            result.append('     ' +
                           self._translate(_("SourceDisplayWidget-label",
                                             default="Selected"))
                           )
             result.append('    </div>')
             result.append('    <div class="field">')
-            result.append(u'     ' +
+            result.append('     ' +
                           self._translate(_("SourceDisplayWidget-missing",
                                             default="Nothing"))
                           )
@@ -216,20 +227,20 @@ class SourceInputWidget(InputWidget):
             try:
                 term = self.terms.getTerm(value)
             except LookupError:
-                result.append(u'  ' +
+                result.append('  ' +
                               self._translate(_("SourceDisplayWidget-missing",
                                                 default="Nothing Valid"))
                               )
             else:
                 result.append('  <div class="row">')
                 result.append('    <div class="label">')
-                result.append(u'     ' +
+                result.append('     ' +
                               self._translate(_("SourceDisplayWidget-label",
                                                 default="Selected"))
                               )
                 result.append('    </div>')
                 result.append('    <div class="field">')
-                result.append(u'     ' + self.renderTermForDisplay(term))
+                result.append('     ' + self.renderTermForDisplay(term))
                 result.append('    </div>')
                 result.append('  </div>')
                 result.append(
@@ -476,7 +487,7 @@ class SourceListInputWidget(SourceInputWidget):
             '</select>\n'
             '<input type="submit" name="%s.apply" value="%s" />'
             % (name,
-               '\n'.join([('<option value="%s">%s</option>' % (token, title))
+               '\n'.join([(f'<option value="{token}">{title}</option>')
                           for (title, token) in terms]),
                name,
                apply)
@@ -512,7 +523,7 @@ class SourceListInputWidget(SourceInputWidget):
 
 @implementer(IVocabularyTokenized)
 @adapter(IIterableSource)
-class IterableSourceVocabulary(object):
+class IterableSourceVocabulary:
 
     """Adapts an iterable source into a legacy vocabulary.
 
@@ -534,7 +545,7 @@ class IterableSourceVocabulary(object):
         return self.getTerm(value)
 
     def __iter__(self):
-        return imap(
+        return map(
             lambda value: self.getTerm(value), self.source.__iter__())
 
     def __len__(self):
@@ -548,7 +559,7 @@ class SourceSelectWidget(SelectWidget):
     """Provide a selection list for the item."""
 
     def __init__(self, field, source, request):
-        super(SourceSelectWidget, self).__init__(
+        super().__init__(
             field, IterableSourceVocabulary(source, request), request)
         # BBB
         if not zope.formlib.itemswidgets.EXPLICIT_EMPTY_SELECTION:
@@ -568,7 +579,7 @@ class SourceRadioWidget(RadioWidget):
     """Radio widget for single item choices."""
 
     def __init__(self, field, source, request):
-        super(SourceRadioWidget, self).__init__(
+        super().__init__(
             field, IterableSourceVocabulary(source, request), request)
 
 
@@ -576,7 +587,7 @@ class SourceMultiSelectWidget(MultiSelectWidget):
     """A multi-selection widget with ordering support."""
 
     def __init__(self, field, source, request):
-        super(SourceMultiSelectWidget, self).__init__(
+        super().__init__(
             field, IterableSourceVocabulary(source, request), request)
 
 
@@ -584,7 +595,7 @@ class SourceOrderedMultiSelectWidget(OrderedMultiSelectWidget):
     """A multi-selection widget with ordering support."""
 
     def __init__(self, field, source, request):
-        super(SourceOrderedMultiSelectWidget, self).__init__(
+        super().__init__(
             field, IterableSourceVocabulary(source, request), request)
 
 
@@ -592,7 +603,7 @@ class SourceMultiSelectSetWidget(MultiSelectSetWidget):
     """Provide a selection list for the set to be selected."""
 
     def __init__(self, field, source, request):
-        super(SourceMultiSelectSetWidget, self).__init__(
+        super().__init__(
             field, IterableSourceVocabulary(source, request), request)
 
 
@@ -600,7 +611,7 @@ class SourceMultiSelectFrozenSetWidget(MultiSelectFrozenSetWidget):
     """Provide a selection list for the frozenset to be selected."""
 
     def __init__(self, field, source, request):
-        super(SourceMultiSelectFrozenSetWidget, self).__init__(
+        super().__init__(
             field, IterableSourceVocabulary(source, request), request)
 
 
@@ -608,5 +619,5 @@ class SourceMultiCheckBoxWidget(MultiCheckBoxWidget):
     """Provide a list of checkboxes that provide the choice for the list."""
 
     def __init__(self, field, source, request):
-        super(SourceMultiCheckBoxWidget, self).__init__(
+        super().__init__(
             field, IterableSourceVocabulary(source, request), request)
