@@ -13,17 +13,19 @@
 ##############################################################################
 """Decimal Widget tests
 """
-import unittest
 import decimal
 import doctest
-from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
-from zope.formlib.interfaces import IInputWidget
-from zope.formlib.widgets import DecimalWidget
-from zope.formlib.interfaces import ConversionError, WidgetInputError
-from zope.interface.verify import verifyClass
+import unittest
 
+from zope.interface.verify import verifyClass
 from zope.schema import Decimal
 
+from zope.formlib.interfaces import ConversionError
+from zope.formlib.interfaces import IInputWidget
+from zope.formlib.interfaces import WidgetInputError
+from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
+from zope.formlib.widgets import DecimalWidget
+
 
 class DecimalWidgetTest(SimpleInputWidgetTest):
     """Documents and tests the float widget.
@@ -39,23 +41,23 @@ class DecimalWidgetTest(SimpleInputWidgetTest):
         del self._widget.request.form['field.foo']
         self.assertFalse(self._widget.hasInput())
         # widget has input, even if input is an empty string
-        self._widget.request.form['field.foo'] = u''
+        self._widget.request.form['field.foo'] = ''
         self.assertTrue(self._widget.hasInput())
-        self._widget.request.form['field.foo'] = u'123'
+        self._widget.request.form['field.foo'] = '123'
         self.assertTrue(self._widget.hasInput())
 
     def test_getInputValue(self):
-        self._widget.request.form['field.foo'] = u''
+        self._widget.request.form['field.foo'] = ''
         self.assertRaises(WidgetInputError, self._widget.getInputValue)
-        self._widget.request.form['field.foo'] = u'123.45'
+        self._widget.request.form['field.foo'] = '123.45'
         self.assertEqual(self._widget.getInputValue(),
                          decimal.Decimal("123.45"))
-        self._widget.request.form['field.foo'] = u'abc'
+        self._widget.request.form['field.foo'] = 'abc'
         self.assertRaises(ConversionError, self._widget.getInputValue)
 
 
 def test_suite():
     return unittest.TestSuite((
-        unittest.makeSuite(DecimalWidgetTest),
+        unittest.defaultTestLoader.loadTestsFromTestCase(DecimalWidgetTest),
         doctest.DocTestSuite(),
     ))
