@@ -15,10 +15,9 @@
 """
 import unittest
 from doctest import DocTestSuite
-from .support import checker
 
 
 def test_suite():
     return unittest.TestSuite((
-        DocTestSuite('zope.formlib.exception', checker=checker),
+        DocTestSuite('zope.formlib.exception'),
     ))
