@@ -13,19 +13,22 @@
 ##############################################################################
 """Decimal Widget Functional Tests
 """
+import decimal
 import unittest
 
-import decimal
-from zope.interface import Interface, implementer
-from zope.schema import Decimal, Choice
-from zope.formlib import form
-from zope.publisher.browser import TestRequest
-from zope.formlib.tests.support import patternExists
-from zope.formlib.widgets import (
-    DecimalWidget,
-    DropdownWidget, ChoiceInputWidget)
-from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
 import zope.schema.interfaces
+from zope.interface import Interface
+from zope.interface import implementer
+from zope.publisher.browser import TestRequest
+from zope.schema import Choice
+from zope.schema import Decimal
+
+from zope.formlib import form
+from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
+from zope.formlib.tests.support import patternExists
+from zope.formlib.widgets import ChoiceInputWidget
+from zope.formlib.widgets import DecimalWidget
+from zope.formlib.widgets import DropdownWidget
 
 
 class IDecimalTest(Interface):
@@ -48,7 +51,7 @@ class IDecimalTest(Interface):
 
 
 @implementer(IDecimalTest)
-class DecimalTest(object):
+class DecimalTest:
 
     def __init__(self):
         self.f1 = None
@@ -93,7 +96,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.f1'] = '1.123'
         request.form['form.f2'] = '2.23456789012345'
         request.form['form.f3'] = '11.1'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         Form(foo, request)()
 
         # check new values in object
@@ -108,7 +111,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.f1'] = ''
         request.form['form.f2'] = ''
         request.form['form.f3'] = '1.1'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         Form(foo, request)()
 
         # check new values in object
@@ -124,7 +127,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.f1'] = ''
         request.form['form.f2'] = ''
         request.form['form.f3'] = ''
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         html = Form(foo, request)()
 
         # confirm error msgs
@@ -138,7 +141,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit a value for f3 that isn't allowed
         request.form['form.f3'] = '10000'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         html = Form(foo, request)()
 
         f3_index = html.find('form.f3')
@@ -151,7 +154,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit value for f1 that is too low
         request.form['form.f1'] = '-1'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         html = Form(foo, request)()
 
         f1_index = html.find('form.f1')
@@ -162,7 +165,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit value for f1 that is too high
         request.form['form.f1'] = '1000.2'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         html = Form(foo, request)()
 
         f1_index = html.find('form.f1')
@@ -183,7 +186,7 @@ class Test(FunctionalWidgetTestCase):
         # submit change with only f2 present -- note that required
         # field f1 is omitted, which should not cause a validation error
         request.form['form.f2'] = ''
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         Form(foo, request)()
 
         # check new value in object
@@ -197,7 +200,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit value for f1 that cannot be convert to an float
         request.form['form.f1'] = 'foo'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         html = Form(foo, request)()
 
         f1_index = html.find('form.f1')
@@ -209,5 +212,5 @@ class Test(FunctionalWidgetTestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(Test))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(Test))
     return suite
