@@ -15,16 +15,19 @@
 """
 import unittest
 
-from zope.interface import Interface, implementer
-from zope.schema import Int, Choice
-from zope.formlib import form
-from zope.publisher.browser import TestRequest
-from zope.formlib.tests.support import patternExists
-from zope.formlib.widgets import (
-    IntWidget,
-    DropdownWidget, ChoiceInputWidget)
-from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
 import zope.schema.interfaces
+from zope.interface import Interface
+from zope.interface import implementer
+from zope.publisher.browser import TestRequest
+from zope.schema import Choice
+from zope.schema import Int
+
+from zope.formlib import form
+from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
+from zope.formlib.tests.support import patternExists
+from zope.formlib.widgets import ChoiceInputWidget
+from zope.formlib.widgets import DropdownWidget
+from zope.formlib.widgets import IntWidget
 
 
 class IIntTest(Interface):
@@ -53,7 +56,7 @@ class IIntTest2(Interface):
 
 
 @implementer(IIntTest)
-class IntTest(object):
+class IntTest:
 
     def __init__(self):
         self.i1 = None
@@ -62,7 +65,7 @@ class IntTest(object):
 
 
 @implementer(IIntTest2)
-class IntTest2(object):
+class IntTest2:
 
     def __init__(self):
         self.i1 = 10
@@ -109,7 +112,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.i1'] = '1'
         request.form['form.i2'] = '2'
         request.form['form.i3'] = '3'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         Form(foo, request)()
 
@@ -126,7 +129,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.i1'] = '1'
         request.form['form.i2'] = ''
         request.form['form.i3-empty-marker'] = ''
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         Form(foo, request)()
 
@@ -155,7 +158,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit form as if top item is selected
         request.form['form.i1-empty-marker'] = '1'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
         html = Form2(foo, request)()
 
         # confirm new value is -1 -- i1.missing_value
@@ -169,7 +172,7 @@ class Test(FunctionalWidgetTestCase):
         request.form['form.i1'] = ''
         request.form['form.i2'] = ''
         request.form['form.i3'] = ''
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         html = Form(foo, request)()
 
@@ -187,7 +190,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit a value for i3 that isn't allowed
         request.form['form.i3'] = '12'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         html = Form(foo, request)()
 
@@ -202,7 +205,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit value for i1 that is too low
         request.form['form.i1'] = '-1'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         html = Form(foo, request)()
 
@@ -210,7 +213,7 @@ class Test(FunctionalWidgetTestCase):
 
         # submit value for i1 that is too high
         request.form['form.i1'] = '11'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         html = Form(foo, request)()
 
@@ -227,7 +230,7 @@ class Test(FunctionalWidgetTestCase):
         # submit change with only i2 present -- note that required
         # field i1 is omitted, which should not cause a validation error
         request.form['form.i2'] = ''
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         Form(foo, request)()
 
@@ -241,7 +244,7 @@ class Test(FunctionalWidgetTestCase):
         request = TestRequest()
 
         request.form['form.i1'] = 'foo'
-        request.form['form.actions.apply'] = u''
+        request.form['form.actions.apply'] = ''
 
         html = Form(foo, request)()
 
@@ -250,5 +253,5 @@ class Test(FunctionalWidgetTestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(Test))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(Test))
     return suite
