@@ -13,24 +13,27 @@
 ##############################################################################
 """Test object widget
 """
+import os
 import unittest
 
-from zope.pagetemplate.pagetemplate import PageTemplate
+import zope.schema.interfaces
 import zope.traversing.interfaces
 from zope.component import provideAdapter
-from zope.traversing.adapters import DefaultTraversable
 from zope.component.testing import PlacelessSetup
-from zope.interface import Interface, implementer
-from zope.schema import TextLine, Object
-from zope.formlib import form
-from zope.publisher.browser import TestRequest
-from zope.formlib.widgets import ObjectWidget
-from zope.formlib.tests.support import VerifyResults
-import zope.schema.interfaces
-from zope.traversing.testing import setUp as traversingSetUp
 from zope.configuration import xmlconfig
+from zope.interface import Interface
+from zope.interface import implementer
+from zope.pagetemplate.pagetemplate import PageTemplate
+from zope.publisher.browser import TestRequest
+from zope.schema import Object
+from zope.schema import TextLine
+from zope.traversing.adapters import DefaultTraversable
+from zope.traversing.testing import setUp as traversingSetUp
+
 import zope.formlib
-import os
+from zope.formlib import form
+from zope.formlib.tests.support import VerifyResults
+from zope.formlib.widgets import ObjectWidget
 
 
 class ITestContact(Interface):
@@ -39,7 +42,7 @@ class ITestContact(Interface):
 
 
 @implementer(ITestContact)
-class TestContact(object):
+class TestContact:
     pass
 
 
@@ -50,7 +53,7 @@ class Form(form.EditForm):
 class Test(PlacelessSetup, unittest.TestCase, VerifyResults):
 
     def setUp(self):
-        super(Test, self).setUp()
+        super().setUp()
         traversingSetUp()
         # XXX this whole test setup is rather involved. Is there a
         # simpler way to publish widget_macros.pt? Probably.
@@ -64,7 +67,7 @@ class Test(PlacelessSetup, unittest.TestCase, VerifyResults):
         widget_macros = os.path.join(os.path.dirname(zope.formlib.__file__),
                                      'widget_macros.pt')
 
-        f = open(widget_macros, 'r')
+        f = open(widget_macros)
         data = f.read()
         f.close()
         macro_template.write(data)
@@ -82,7 +85,7 @@ class Test(PlacelessSetup, unittest.TestCase, VerifyResults):
 
     def test_new(self):
         request = TestRequest()
-        field = Object(ITestContact, __name__=u'foo')
+        field = Object(ITestContact, __name__='foo')
 
         widget = ObjectWidget(field, request, TestContact)
 
@@ -95,16 +98,16 @@ class Test(PlacelessSetup, unittest.TestCase, VerifyResults):
 
     def test_edit(self):
         request = TestRequest(form={
-            'field.foo.name': u'fred',
-            'field.foo.email': u'fred@fred.com'
+            'field.foo.name': 'fred',
+            'field.foo.email': 'fred@fred.com'
         })
-        field = Object(ITestContact, __name__=u'foo')
+        field = Object(ITestContact, __name__='foo')
         widget = ObjectWidget(field, request, TestContact)
         self.assertEqual(int(widget.hasInput()), 1)
         o = widget.getInputValue()
         self.assertEqual(hasattr(o, 'name'), 1)
-        self.assertEqual(o.name, u'fred')
-        self.assertEqual(o.email, u'fred@fred.com')
+        self.assertEqual(o.name, 'fred')
+        self.assertEqual(o.email, 'fred@fred.com')
         check_list = (
             'input', 'name="field.foo.name"', 'value="fred"',
             'input', 'name="field.foo.email"', 'value="fred@fred.com"',
@@ -114,5 +117,5 @@ class Test(PlacelessSetup, unittest.TestCase, VerifyResults):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(Test))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(Test))
     return suite
