@@ -15,35 +15,37 @@
 """
 import unittest
 
-from zope.interface import Interface, implementer
-from zope.schema import Choice
-from zope.formlib import form
-from zope.publisher.browser import TestRequest
-from zope.formlib.tests.support import patternExists
-from zope.formlib.widgets import (
-    TextWidget,
-    DropdownWidget, ChoiceInputWidget)
-from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
 import zope.schema.interfaces
+from zope.interface import Interface
+from zope.interface import implementer
+from zope.publisher.browser import TestRequest
+from zope.schema import Choice
+
+from zope.formlib import form
+from zope.formlib.tests.functionalsupport import FunctionalWidgetTestCase
+from zope.formlib.tests.support import patternExists
+from zope.formlib.widgets import ChoiceInputWidget
+from zope.formlib.widgets import DropdownWidget
+from zope.formlib.widgets import TextWidget
 
 
 class IRadioTest(Interface):
 
     s3 = Choice(
         required=False,
-        values=(u'Bob', u'is', u'Your', u'Uncle'))
+        values=('Bob', 'is', 'Your', 'Uncle'))
 
     s4 = Choice(
         required=True,
-        values=(u'1', u'2', u'3'))
+        values=('1', '2', '3'))
 
 
 @implementer(IRadioTest)
-class RadioTest(object):
+class RadioTest:
 
     def __init__(self):
         self.s3 = None
-        self.s4 = u'1'
+        self.s4 = '1'
 
 
 class Form(form.EditForm):
@@ -103,9 +105,9 @@ class Test(FunctionalWidgetTestCase):
             html))
 
         request = TestRequest()
-        request.form['form.s3'] = u'Bob'
-        request.form['form.s4'] = u'2'
-        request.form['form.actions.apply'] = u''
+        request.form['form.s3'] = 'Bob'
+        request.form['form.s4'] = '2'
+        request.form['form.actions.apply'] = ''
 
         # display edit view
         html = Form(foo, request)()
@@ -126,8 +128,8 @@ class Test(FunctionalWidgetTestCase):
             html))
 
         request = TestRequest()
-        request.form['form.s3'] = u''
-        request.form['form.actions.apply'] = u''
+        request.form['form.s3'] = ''
+        request.form['form.actions.apply'] = ''
 
         html = Form(foo, request)()
         self.assertTrue(patternExists(
@@ -147,5 +149,5 @@ class Test(FunctionalWidgetTestCase):
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(unittest.makeSuite(Test))
+    suite.addTest(unittest.defaultTestLoader.loadTestsFromTestCase(Test))
     return suite
