@@ -13,16 +13,18 @@
 ##############################################################################
 """Integer Widget Tests
 """
-import unittest
 import doctest
-from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
-from zope.formlib.interfaces import IInputWidget
-from zope.formlib.widgets import IntWidget
-from zope.formlib.interfaces import ConversionError, WidgetInputError
-from zope.interface.verify import verifyClass
+import unittest
 
+from zope.interface.verify import verifyClass
 from zope.schema import Int
 
+from zope.formlib.interfaces import ConversionError
+from zope.formlib.interfaces import IInputWidget
+from zope.formlib.interfaces import WidgetInputError
+from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
+from zope.formlib.widgets import IntWidget
+
 
 class IntWidgetTest(SimpleInputWidgetTest):
     """Documents and tests the int widget.
@@ -38,22 +40,22 @@ class IntWidgetTest(SimpleInputWidgetTest):
         del self._widget.request.form['field.foo']
         self.assertFalse(self._widget.hasInput())
         # widget has input, even if input is an empty string
-        self._widget.request.form['field.foo'] = u''
+        self._widget.request.form['field.foo'] = ''
         self.assertTrue(self._widget.hasInput())
-        self._widget.request.form['field.foo'] = u'123'
+        self._widget.request.form['field.foo'] = '123'
         self.assertTrue(self._widget.hasInput())
 
     def test_getInputValue(self):
-        self._widget.request.form['field.foo'] = u''
+        self._widget.request.form['field.foo'] = ''
         self.assertRaises(WidgetInputError, self._widget.getInputValue)
-        self._widget.request.form['field.foo'] = u'123'
+        self._widget.request.form['field.foo'] = '123'
         self.assertEqual(self._widget.getInputValue(), 123)
-        self._widget.request.form['field.foo'] = u'abc'
+        self._widget.request.form['field.foo'] = 'abc'
         self.assertRaises(ConversionError, self._widget.getInputValue)
 
 
 def test_suite():
     return unittest.TestSuite((
-        unittest.makeSuite(IntWidgetTest),
+        unittest.defaultTestLoader.loadTestsFromTestCase(IntWidgetTest),
         doctest.DocTestSuite(),
     ))
