@@ -13,13 +13,15 @@
 ##############################################################################
 """Password Widget Tests
 """
-import unittest
 import doctest
-from zope.formlib.interfaces import IInputWidget
-from zope.formlib.widgets import PasswordWidget
-from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
+import unittest
+
 from zope.interface.verify import verifyClass
 
+from zope.formlib.interfaces import IInputWidget
+from zope.formlib.tests.test_browserwidget import SimpleInputWidgetTest
+from zope.formlib.widgets import PasswordWidget
+
 
 class PasswordWidgetTest(SimpleInputWidgetTest):
     """Documents and tests the password widget.
@@ -52,6 +54,6 @@ class PasswordWidgetTest(SimpleInputWidgetTest):
 
 def test_suite():
     return unittest.TestSuite((
-        unittest.makeSuite(PasswordWidgetTest),
+        unittest.defaultTestLoader.loadTestsFromTestCase(PasswordWidgetTest),
         doctest.DocTestSuite(),
     ))
