@@ -13,12 +13,11 @@
 ##############################################################################
 """Source Widget Tests
 """
+import doctest
+
 from zope.component import testing
-from .support import checker
 
 
 def test_suite():
-    import doctest
     return doctest.DocFileSuite(
-        '../source.rst',
-        setUp=testing.setUp, tearDown=testing.tearDown, checker=checker)
+        '../source.rst', setUp=testing.setUp, tearDown=testing.tearDown)
