@@ -15,11 +15,9 @@
 """
 import unittest
 from doctest import DocTestSuite
-from .support import checker
 
 
 def test_suite():
     suite = unittest.TestSuite()
-    suite.addTest(
-        DocTestSuite("zope.formlib.textwidgets", checker=checker))
+    suite.addTest(DocTestSuite("zope.formlib.textwidgets"))
     return suite
